@@ -49,7 +49,7 @@
  *   FhcBrowsingListener, FhcShowDialog.js,
  *   FhcPredefinedRegexp.js
  */
-const HistoryWindowControl = {
+var HistoryWindowControl = {
   treeView: null,
   countLabel: 0,
   selectCountLabel: "",
@@ -416,13 +416,13 @@ const HistoryWindowControl = {
 
       // check if regexp menu needs rebuild
       var keyStore = "FhcGlobalRegexpListDirty";
-      var ref = Application.storage.get(keyStore, "");
+      var ref = sessionStore.get(keyStore, "");
       if ("okay" != ref || regexpMenu.childNodes.length <= 4) {
         // menu never built before ("") or dirty ("dirty"), rebuild both menus
         this._rebuildRegexpMenu(regexpData, "N", document.getElementById("regexp-namelist-menu"));
         this._rebuildRegexpMenu(regexpData, "V", document.getElementById("regexp-list-menu"));
 
-        Application.storage.set(keyStore, "okay");
+        sessionStore.set(keyStore, "okay");
       }
       //delete regexpData;
 
@@ -555,6 +555,7 @@ const HistoryWindowControl = {
     document.getElementById("mnDelete").setAttribute("disabled", 0 == selected.length);
     document.getElementById("mnDeleteName").setAttribute("disabled", 1 != selected.length);
     document.getElementById("mnDeleteValue").setAttribute("disabled", 1 != selected.length);
+    document.getElementById("mnCopyValue").setAttribute("disabled", 1 != selected.length);
     document.getElementById("mnAddCleanup").setAttribute("disabled", 0 == selected.length);
     document.getElementById("mnAddProtect").setAttribute("disabled", 0 == selected.length);
     return true;
@@ -567,6 +568,7 @@ const HistoryWindowControl = {
     document.getElementById("mnbarFhDelete").setAttribute("disabled", 0 == selected.length);
     document.getElementById("mnbarFhDeleteName").setAttribute("disabled", 1 != selected.length);
     document.getElementById("mnbarFhDeleteValue").setAttribute("disabled", 1 != selected.length);
+    document.getElementById("mnbarFhCopyValue").setAttribute("disabled", 1 != selected.length);
     document.getElementById("mnbarFhAddCleanup").setAttribute("disabled", 0 == selected.length);
     document.getElementById("mnbarFhAddProtect").setAttribute("disabled", 0 == selected.length);
 
@@ -636,6 +638,9 @@ const HistoryWindowControl = {
         case "DeleteValue":
           this._removeAllWithValue(selected[0].value);
           break;
+      case "CopyValue":
+          this._copyValueToClipboard(selected[0].value);
+          break;
       }
     }
   },
@@ -2276,6 +2281,13 @@ const HistoryWindowControl = {
     }
   },
   
+  // copy a value to the clipboard
+  _copyValueToClipboard: function(value) {
+    var gClipboardHelper = Components.classes["@mozilla.org/widget/clipboardhelper;1"]
+                           .getService(Components.interfaces.nsIClipboardHelper);
+    gClipboardHelper.copyString(value);
+  },
+  
   // Delete entries
   _deleteEntries: function(entries) {
     if (this.dbHandler.deleteEntries(entries)) {
@@ -2457,4 +2469,6 @@ const HistoryWindowControl = {
       this.browserListener = null;
     }
   }
-}
\ No newline at end of file
+};
+
+Components.utils.import("chrome://formhistory/content/utils/FhcSessionStorage.jsm", HistoryWindowControl);
\ No newline at end of file
