@@ -43,7 +43,7 @@
  *   FhcDbHandler.js, FhcShowDialog.js.
  *
  */
-const MultilineWindowControl = {
+var MultilineWindowControl = {
   // nsITreeView attributes
   treeBox: null,
   rowCount: 0,
@@ -174,6 +174,7 @@ const MultilineWindowControl = {
    */
   menubarPopup: function(event) {
     var selectCount = this.getSelectCount();
+    document.getElementById("mnbarMlCopyToClipboard").setAttribute("disabled", 1 != selectCount);
     document.getElementById("mnbarMlDelete").setAttribute("disabled", 0 == selectCount);
     return true;
   },
@@ -503,10 +504,10 @@ const MultilineWindowControl = {
   },
 
   /**
-   * Get the number of selected cleanup criteria.
+   * Get the number of selected multiline criteria.
    *
    * @returns {number}
-   *          the number of selected cleanup criteria items
+   *          the number of selected multiline criteria items
    */
   getSelectCount: function() {
     var selected = 0;
