@@ -42,7 +42,7 @@
  *   FhcUtil.js, FhcPreferenceHandler.js, FhcDbHandler.js
  */
 
-const FhcManageFormHistoryOverlay = {
+var FhcManageFormHistoryOverlay = {
   observerService:        null,
   prefHandler:            null,
   dbHandler:              null,
@@ -426,7 +426,7 @@ const FhcManageFormHistoryOverlay = {
   notifyStoreChanged: function() {
     var observerService = Components.classes["@mozilla.org/observer-service;1"]
                             .getService(Components.interfaces.nsIObserverService);
-    observerService.notifyObservers(null, "sessionstore-state-write", "");
+    observerService.notifyObservers(null, "sessionstore-state-write-complete", "");
   },
 
   destroyTimer: function() {
